window.Gleam.initSearch([{"doc":"gleamstral","title":"gleamstral","content":"# gleamstral\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamstral)](https://hex.pm/packages/gleamstral)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamstral/)\n\nA Gleam client library for the Mistral AI API, providing type-safe access to Mistral&#39;s powerful language models, embeddings, and agents.\n\n## Overview\n\nGleamstral enables Gleam applications to seamlessly integrate with Mistral AI&#39;s capabilities, including:\n\n- Chat completions with various Mistral models (Large, Small, Ministral, etc.)\n- Function/tool calling support\n- Embeddings generation\n- Agent API integration\n- Image analysis with Pixtral models\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleamstral&gt;.\n\n## Installation\n\n```sh\ngleam add gleamstral\n```\n\n## Getting an API key\n\nYou can get an API key **for free** from Mistral [La Plateforme](https://console.mistral.ai/).\n\n## Quick Example\n\n```gleam\nimport gleam/io\nimport gleam/httpc\nimport gleam/list\nimport gleamstral/client\nimport gleamstral/chat\nimport gleamstral/message\nimport gleamstral/model\n\npub fn main() {\n  // Create a Mistral client with your API key\n  let client = client.new(&quot;your-mistral-api-key&quot;)\n\n  // Set up a chat with Mistral Large model\n  let chat_client = chat.new(client) |&gt; chat.set_temperature(0.7)\n\n  // Define a list of one or many messages to send to the model\n  let messages = [\n    message.UserMessage(message.TextContent(&quot;Explain brievly what is Gleam&quot;)),\n  ]\n\n  // Send the request and get a response from the model\n  let assert Ok(response) =\n    chat_client\n    |&gt; chat.complete_request(model.MistralSmall, messages)\n    |&gt; httpc.send\n\n  let assert Ok(response) = chat.handle_response(response)\n  let assert Ok(choice) = list.first(response.choices)\n  let assert message.AssistantMessage(content, _, _) = choice.message\n\n  io.println(&quot;Response: &quot; &lt;&gt; content) // &quot;Gleam is a very cool language [...]&quot;\n}\n```\n\n## Key Features\n\n### Chat Completions with Vision\n\nGleamstral supports multimodal inputs, allowing you to send both text and images to vision-enabled models like Pixtral:\n\n```gleam\n// Create a message with an image\nlet messages = [\n  message.UserMessage(\n    message.MultiContent([\n      message.Text(&quot;What&#39;s in this image?&quot;),\n      message.ImageUrl(&quot;https://gleam.run/images/lucy/lucy.svg&quot;)\n    ])\n  )\n]\n\n// Use a Pixtral model for image analysis\nlet assert Ok(response) =\n  chat.new(client)\n  |&gt; chat.complete_request(model.PixtralLarge, messages)\n  |&gt; httpc.send\n\nlet assert Ok(response) = chat.handle_response(response)\n// Get the first choice from the response\nlet assert Ok(choice) = list.first(response.choices)\nlet assert message.AssistantMessage(content, _, _) = choice.message\n\nio.println(&quot;Response: &quot; &lt;&gt; content) // &quot;This is a picture of the cute star lucy&quot;\n```\n\n### Agent API\n\nAccess Mistral&#39;s Agent API to utilize pre-configured agents for specific tasks:\n\n```gleam\n// Get your agent ID from the Mistral console\nlet agent_id = &quot;your-agent-id&quot;\n\n// Call the agent with your agent ID and messages\nlet assert Ok(response) =\n  agent.new(client)\n  |&gt; agent.complete_request(agent_id, messages)\n  |&gt; httpc.send\n\nlet assert Ok(response) = agent.handle_response(response)\n```\n\n### Embeddings Generation\n\nGenerate vector embeddings for text to enable semantic search, clustering, or other vector operations:\n\n```gleam\n// Generate embeddings for a text input\nlet assert Ok(response) =\n  embeddings.new(client)\n  |&gt; embeddings.create_request(model.MistralEmbed, [&quot;Your text to embed&quot;])\n  |&gt; httpc.send\n\nlet assert Ok(response) = embeddings.handle_response(response)\n```\n\n### Tool/Function Calling\n\nDefine tools that the model can use to call functions in your application:\n\n```gleam\n// Define a tool\nlet weather_tool = tool.new_basic_function(\n  &quot;get_weather&quot;,\n  &quot;Get the current weather in a location&quot;,\n  [\n    #(&quot;location&quot;, StringProperty(&quot;the name of the city&quot;)),\n    #(&quot;unit&quot;, StringProperty(&quot;the unit to use for the temp. F or C&quot;))\n  ]\n)\n\n// Create a chat client with the tool\nlet assert Ok(response) =\n  chat.new(client)\n  |&gt; chat.set_tools([weather_tool])\n  |&gt; chat.complete_request(model.MistralSmall, messages)\n  |&gt; httpc.send\n\nlet assert Ok(response) = chat.handle_response(response)\n```\n\n### Structured Outputs\n\nReceive structured outputs from the model, based on a JSON schema:\n\n```gleam\npub type Book {\n  Book(name: String, authors: List(String))\n}\n\nfn book_decoder() -&gt; blueprint.Decoder(Book) {\n  blueprint.decode2(\n    Book,\n    blueprint.field(&quot;name&quot;, blueprint.string()),\n    blueprint.field(&quot;authors&quot;, blueprint.list(blueprint.string())),\n  )\n}\nlet json_schema = blueprint.generate_json_schema(book_decoder())\n\n// Create a chat client with structured output\nlet assert Ok(response) =\n  chat.new(client)\n  |&gt; chat.set_response_format(chat.JsonSchema(\n      schema: json_schema,\n      name: &quot;book&quot;,\n    ))\n  |&gt; chat.complete_request(model.MistralSmall, messages)\n  |&gt; httpc.send\n```\n\n## Examples\n\nThe `examples/` directory contains several ready-to-use examples demonstrating the library&#39;s capabilities:\n\n- `text_completion.gleam`: Basic text completion example\n- `agent.gleam`: Shows how to use the Mistral Agent API\n- `basic_tool.gleam`: Demonstrates tool/function calling functionality\n- `embeddings.gleam`: Illustrates how to generate and use embeddings\n- `image_analysis.gleam`: Shows how to perform image analysis with Pixtral models\n- `json_object.gleam`: Example of JSON output from the model\n- `structured_output.gleam`: Demonstrates how to use structured outputs\n\nTo run any example:\n\n```sh\ncd examples\ngleam run -m example_name  # e.g., gleam run -m agent\n```\n\nNote: You&#39;ll need to set your Mistral API key in an `.env` file or as an environment variable.\n\n## Roadmap\n\n- [x] Decouple the HTTP client from the library\n- [x] Add support for structured outputs (JSON, JSON Schema, etc.)\n- [x] Improve tool calling support\n- [ ] Add example for streaming responses\n- [ ] Add more tests and documentation\n\n## Contributing\n\nContributions are welcome! Please open an issue or submit a pull request.\n\n## License\n\nThis project is licensed under the MIT License.\n","url":"index.html"},{"doc":"gleamstral/client","title":"Client","content":"pub type Client {\n  Client(api_key: String)\n}\n Client for interacting with the Mistral AI API\n\n Contains the API key required for authentication\nClient(api_key: String)\n\n\nSynonyms:\ngleamstral/client.Client\ngleamstral/client Client","url":"gleamstral/client.html#Client"},{"doc":"gleamstral/client","title":"Error","content":"pub type Error {\n  RateLimitExceeded\n  Unauthorized\n  Unknown(String)\n}\n Represents possible errors that can occur when interacting with the Mistral AI API\n\n - `RateLimitExceeded`: Returned when API rate limits have been reached\n - `Unauthorized`: Returned when API key is invalid or missing\n - `Unknown`: Returned for any other error, with the error message as a string\nRateLimitExceeded\n\n\nUnauthorized\n\n\nUnknown(String)\n\n\nSynonyms:\ngleamstral/client.Error\ngleamstral/client Error","url":"gleamstral/client.html#Error"},{"doc":"gleamstral/client","title":"api_endpoint","content":"pub const api_endpoint: String\n\nSynonyms:\ngleamstral/client.api_endpoint\ngleamstral/client api_endpoint","url":"gleamstral/client.html#api_endpoint"},{"doc":"gleamstral/client","title":"error_decoder","content":"pub fn error_decoder() -&gt; Decoder(Error)\n\nSynonyms:\ngleamstral/client.error_decoder\ngleamstral/client error_decoder","url":"gleamstral/client.html#error_decoder"},{"doc":"gleamstral/client","title":"handle_response","content":"pub fn handle_response(\n  response: Response(String),\n  using decoder: Decoder(a),\n) -&gt; Result(a, Error)\n Handle HTTP responses from the Mistral AI API\n\n Takes a response and a decoder, and returns either the decoded response\n or an appropriate error.\n\n The generic type parameters allow this function to work with different\n request and response types.\nSynonyms:\ngleamstral/client.handle_response\ngleamstral/client handle_response","url":"gleamstral/client.html#handle_response"},{"doc":"gleamstral/client","title":"new","content":"pub fn new(api_key: String) -&gt; Client\n Creates a new Mistral AI client with the provided API key and HTTP client\n\n ## Example\n\n \n // Using gleam_httpc\n import gleam_httpc\n let client = client.new(&quot;your-api-key-here&quot;, httpc.send)\n \n // Or using another HTTP client, like gleam_hackney\n import hackney\n let client = client.new(&quot;your-api-key-here&quot;, hackney.send)\n \nSynonyms:\ngleamstral/client.new\ngleamstral/client new","url":"gleamstral/client.html#new"},{"doc":"gleamstral/client","title":"gleamstral/client","content":"","url":"gleamstral/client.html"},{"doc":"gleamstral/tool","title":"FunctionCall","content":"pub type FunctionCall {\n  FunctionCall(name: String, arguments: String)\n}\n Represents a function call within a tool call\n\n Contains the name of the function and its arguments as a JSON string\nFunctionCall(name: String, arguments: String)\n\n\nSynonyms:\ngleamstral/tool.FunctionCall\ngleamstral/tool FunctionCall","url":"gleamstral/tool.html#FunctionCall"},{"doc":"gleamstral/tool","title":"ParameterProperty","content":"pub type ParameterProperty {\n  StringProperty(description: String)\n  IntegerProperty(description: String)\n  NumberProperty(description: String)\n  BooleanProperty(description: String)\n  ArrayProperty(description: String, item_type: String)\n  ObjectProperty(\n    description: String,\n    properties: List(#(String, ParameterProperty)),\n  )\n}\n Property definition for a tool parameter\nStringProperty(description: String)\n A string property type\n\nIntegerProperty(description: String)\n An integer property type\n\nNumberProperty(description: String)\n A number property type (float or integer)\n\nBooleanProperty(description: String)\n A boolean property type\n\nArrayProperty(description: String, item_type: String)\n An array property type with an item type (string, integer, number, boolean)\n\nObjectProperty(\n  description: String,\n  properties: List(#(String, ParameterProperty)),\n)\n An object property type\n\nSynonyms:\ngleamstral/tool.ParameterProperty\ngleamstral/tool ParameterProperty","url":"gleamstral/tool.html#ParameterProperty"},{"doc":"gleamstral/tool","title":"Tool","content":"pub type Tool {\n  Function(\n    name: String,\n    description: String,\n    strict: Bool,\n    parameters: ToolParameters,\n  )\n}\n Represents a tool that can be used by the model\n\n - `Function`: A function tool with name, description, and parameters\nFunction(\n  name: String,\n  description: String,\n  strict: Bool,\n  parameters: ToolParameters,\n)\n\n\nSynonyms:\ngleamstral/tool.Tool\ngleamstral/tool Tool","url":"gleamstral/tool.html#Tool"},{"doc":"gleamstral/tool","title":"ToolCall","content":"pub type ToolCall {\n  ToolCall(\n    id: String,\n    tool_type: String,\n    function: FunctionCall,\n    index: Int,\n  )\n}\n Represents a tool call made by the model\n\n Contains the ID, type, function call details, and index of the tool call\nToolCall(\n  id: String,\n  tool_type: String,\n  function: FunctionCall,\n  index: Int,\n)\n\n\nSynonyms:\ngleamstral/tool.ToolCall\ngleamstral/tool ToolCall","url":"gleamstral/tool.html#ToolCall"},{"doc":"gleamstral/tool","title":"ToolChoice","content":"pub type ToolChoice {\n  Auto\n  None\n  Any\n  Required\n  Choice(Tool)\n}\n Tool choice options for API requests\n\n - `Auto`: Let the model decide when to use tools\n - `None`: Do not use tools\n - `Any`: Allow the model to use any available tool\n - `Required`: Require the model to use tools\n - `Choice(Tool)`: Require the model to use a specific tool\nAuto\n\n\nNone\n\n\nAny\n\n\nRequired\n\n\nChoice(Tool)\n\n\nSynonyms:\ngleamstral/tool.ToolChoice\ngleamstral/tool ToolChoice","url":"gleamstral/tool.html#ToolChoice"},{"doc":"gleamstral/tool","title":"ToolParameters","content":"pub type ToolParameters {\n  ToolParameters(\n    tool_type: String,\n    properties: List(#(String, ParameterProperty)),\n    required: List(String),\n    additional_properties: Bool,\n  )\n}\n Parameters for a tool function\n\n Contains the structure of parameters expected by the tool\nToolParameters(\n  tool_type: String,\n  properties: List(#(String, ParameterProperty)),\n  required: List(String),\n  additional_properties: Bool,\n)\n\n\nSynonyms:\ngleamstral/tool.ToolParameters\ngleamstral/tool ToolParameters","url":"gleamstral/tool.html#ToolParameters"},{"doc":"gleamstral/tool","title":"create_function_tool","content":"pub fn create_function_tool(\n  name: String,\n  description: String,\n  strict: Bool,\n  property_types: List(#(String, String)),\n  required: List(String),\n  additional_properties: Bool,\n) -&gt; Tool\n\nSynonyms:\ngleamstral/tool.create_function_tool\ngleamstral/tool create_function_tool","url":"gleamstral/tool.html#create_function_tool"},{"doc":"gleamstral/tool","title":"new_basic_function","content":"pub fn new_basic_function(\n  name: String,\n  description: String,\n  properties: List(#(String, ParameterProperty)),\n) -&gt; Tool\n Creates a new basic function tool with the given name, description, and properties.\n\n ### Parameters\n - `name`: The name of the function tool.\n - `description`: A brief description of the function tool.\n - `properties`: A list of tuples where each tuple contains a property name and its type.\n\n ### Returns\n A `Tool` representing the function tool.\n\n ### Examples\n \n let tool = new_basic_function(\n   &quot;get_weather&quot;,\n   &quot;Get the current weather for the provided city. Use the unit for the temperature.&quot;,\n   [#(&quot;city&quot;, &quot;string&quot;), #(&quot;unit&quot;, &quot;string&quot;)]\n )\n \nSynonyms:\ngleamstral/tool.new_basic_function\ngleamstral/tool new_basic_function","url":"gleamstral/tool.html#new_basic_function"},{"doc":"gleamstral/tool","title":"tool_call_decoder","content":"pub fn tool_call_decoder() -&gt; Decoder(ToolCall)\n Decodes a tool call from JSON\n\n Used to parse tool calls in model responses\nSynonyms:\ngleamstral/tool.tool_call_decoder\ngleamstral/tool tool_call_decoder","url":"gleamstral/tool.html#tool_call_decoder"},{"doc":"gleamstral/tool","title":"tool_calls_encoder","content":"pub fn tool_calls_encoder(\n  tool_calls: Option(List(ToolCall)),\n) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_calls_encoder\ngleamstral/tool tool_calls_encoder","url":"gleamstral/tool.html#tool_calls_encoder"},{"doc":"gleamstral/tool","title":"tool_choice_encoder","content":"pub fn tool_choice_encoder(tool_choice: ToolChoice) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_choice_encoder\ngleamstral/tool tool_choice_encoder","url":"gleamstral/tool.html#tool_choice_encoder"},{"doc":"gleamstral/tool","title":"tool_decoder","content":"pub fn tool_decoder() -&gt; Decoder(Tool)\n Decodes a tool from JSON\nSynonyms:\ngleamstral/tool.tool_decoder\ngleamstral/tool tool_decoder","url":"gleamstral/tool.html#tool_decoder"},{"doc":"gleamstral/tool","title":"tool_encoder","content":"pub fn tool_encoder(tool: Tool) -&gt; Json\n\nSynonyms:\ngleamstral/tool.tool_encoder\ngleamstral/tool tool_encoder","url":"gleamstral/tool.html#tool_encoder"},{"doc":"gleamstral/tool","title":"gleamstral/tool","content":"","url":"gleamstral/tool.html"},{"doc":"gleamstral/message","title":"ContentPart","content":"pub type ContentPart {\n  Text(String)\n  ImageUrl(String)\n}\n Individual content part in a multi-modal message\n\n - `Text`: Text content\n - `ImageUrl`: URL pointing to an image or a base64 encoded image string\nText(String)\n\n\nImageUrl(String)\n\n\nSynonyms:\ngleamstral/message.ContentPart\ngleamstral/message ContentPart","url":"gleamstral/message.html#ContentPart"},{"doc":"gleamstral/message","title":"Message","content":"pub type Message {\n  SystemMessage(content: MessageContent)\n  UserMessage(content: MessageContent)\n  AssistantMessage(\n    content: String,\n    tool_calls: Option(List(tool.ToolCall)),\n    prefix: Bool,\n  )\n  ToolMessage(\n    content: MessageContent,\n    tool_call_id: String,\n    name: String,\n  )\n}\n Represents a message in a conversation with the AI model\n\n - `SystemMessage`: Instructions or context for the model\n - `UserMessage`: Input from the user to the model\n - `AssistantMessage`: Response from the model, potentially including tool calls\n - `ToolMessage`: Result of a tool function execution\nSystemMessage(content: MessageContent)\n\n\nUserMessage(content: MessageContent)\n\n\nAssistantMessage(\n  content: String,\n  tool_calls: Option(List(tool.ToolCall)),\n  prefix: Bool,\n)\n\n\nToolMessage(\n  content: MessageContent,\n  tool_call_id: String,\n  name: String,\n)\n\n\nSynonyms:\ngleamstral/message.Message\ngleamstral/message Message","url":"gleamstral/message.html#Message"},{"doc":"gleamstral/message","title":"MessageContent","content":"pub type MessageContent {\n  TextContent(String)\n  MultiContent(List(ContentPart))\n}\n Content of a message, which can be text-only or multi-modal\n\n - `TextContent`: Simple text message\n - `MultiContent`: Message with multiple content parts (text and/or images)\nTextContent(String)\n\n\nMultiContent(List(ContentPart))\n\n\nSynonyms:\ngleamstral/message.MessageContent\ngleamstral/message MessageContent","url":"gleamstral/message.html#MessageContent"},{"doc":"gleamstral/message","title":"MessageRole","content":"pub type MessageRole {\n  System\n  User\n  Assistant\n  Tool\n}\n Represents the role of a message in a conversation\n\n - `System`: System messages provide context and instructions to the model\n - `User`: User messages represent the human interacting with the model\n - `Assistant`: Assistant messages are the model&#39;s responses\n - `Tool`: Tool messages contain the results of tool function calls\nSystem\n\n\nUser\n\n\nAssistant\n\n\nTool\n\n\nSynonyms:\ngleamstral/message.MessageRole\ngleamstral/message MessageRole","url":"gleamstral/message.html#MessageRole"},{"doc":"gleamstral/message","title":"message_decoder","content":"pub fn message_decoder() -&gt; Decoder(Message)\n\nSynonyms:\ngleamstral/message.message_decoder\ngleamstral/message message_decoder","url":"gleamstral/message.html#message_decoder"},{"doc":"gleamstral/message","title":"message_encoder","content":"pub fn message_encoder(message: Message) -&gt; Json\n\nSynonyms:\ngleamstral/message.message_encoder\ngleamstral/message message_encoder","url":"gleamstral/message.html#message_encoder"},{"doc":"gleamstral/message","title":"gleamstral/message","content":"","url":"gleamstral/message.html"},{"doc":"gleamstral/agent","title":"Agent","content":"pub type Agent {\n  Agent(client: client.Client, config: Config)\n}\n Represents an agent with configuration options for communication with Mistral AI agents\nAgent(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/agent.Agent\ngleamstral/agent Agent","url":"gleamstral/agent.html#Agent"},{"doc":"gleamstral/agent","title":"ChatCompletionChoice","content":"pub type ChatCompletionChoice {\n  ChatCompletionChoice(\n    index: Int,\n    message: message.Message,\n    finish_reason: FinishReason,\n  )\n}\n\nChatCompletionChoice(\n  index: Int,\n  message: message.Message,\n  finish_reason: FinishReason,\n)\n\n\nSynonyms:\ngleamstral/agent.ChatCompletionChoice\ngleamstral/agent ChatCompletionChoice","url":"gleamstral/agent.html#ChatCompletionChoice"},{"doc":"gleamstral/agent","title":"Config","content":"pub type Config {\n  Config(\n    max_tokens: Int,\n    stream: Bool,\n    stop: List(String),\n    random_seed: Int,\n    response_format: ResponseFormat,\n    tools: List(tool.Tool),\n    tool_choice: tool.ToolChoice,\n    presence_penalty: Float,\n    frequency_penalty: Float,\n    n: Int,\n    prediction: Prediction,\n  )\n}\n\nConfig(\n  max_tokens: Int,\n  stream: Bool,\n  stop: List(String),\n  random_seed: Int,\n  response_format: ResponseFormat,\n  tools: List(tool.Tool),\n  tool_choice: tool.ToolChoice,\n  presence_penalty: Float,\n  frequency_penalty: Float,\n  n: Int,\n  prediction: Prediction,\n)\n\n\nSynonyms:\ngleamstral/agent.Config\ngleamstral/agent Config","url":"gleamstral/agent.html#Config"},{"doc":"gleamstral/agent","title":"FinishReason","content":"pub type FinishReason {\n  Stop\n  Length\n  ModelLength\n  Err\n  ToolCalls\n}\n\nStop\n\n\nLength\n\n\nModelLength\n\n\nErr\n\n\nToolCalls\n\n\nSynonyms:\ngleamstral/agent.FinishReason\ngleamstral/agent FinishReason","url":"gleamstral/agent.html#FinishReason"},{"doc":"gleamstral/agent","title":"Prediction","content":"pub type Prediction {\n  Content(String)\n}\n\nContent(String)\n\n\nSynonyms:\ngleamstral/agent.Prediction\ngleamstral/agent Prediction","url":"gleamstral/agent.html#Prediction"},{"doc":"gleamstral/agent","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    created: Int,\n    model: String,\n    choices: List(ChatCompletionChoice),\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  created: Int,\n  model: String,\n  choices: List(ChatCompletionChoice),\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/agent.Response\ngleamstral/agent Response","url":"gleamstral/agent.html#Response"},{"doc":"gleamstral/agent","title":"ResponseFormat","content":"pub type ResponseFormat {\n  JsonObject\n  Text\n}\n\nJsonObject\n\n\nText\n\n\nSynonyms:\ngleamstral/agent.ResponseFormat\ngleamstral/agent ResponseFormat","url":"gleamstral/agent.html#ResponseFormat"},{"doc":"gleamstral/agent","title":"Usage","content":"pub type Usage {\n  Usage(\n    prompt_tokens: Int,\n    completion_tokens: Int,\n    total_tokens: Int,\n  )\n}\n\nUsage(\n  prompt_tokens: Int,\n  completion_tokens: Int,\n  total_tokens: Int,\n)\n\n\nSynonyms:\ngleamstral/agent.Usage\ngleamstral/agent Usage","url":"gleamstral/agent.html#Usage"},{"doc":"gleamstral/agent","title":"complete_request","content":"pub fn complete_request(\n  agent: Agent,\n  agent_id: String,\n  messages: List(Message),\n) -&gt; Request(String)\n Creates an HTTP request for the Agent API endpoint\n\n This function prepares a request to be sent to the Mistral AI Agent API.\n It needs to be paired with an HTTP client to actually send the request,\n and the response should be handled with client.handle_response using \n the appropriate decoder.\n\n ### Example\n\n \n // Create the request\n let req = agent\n   |&gt; agent.complete_request(&quot;agent-123&quot;, messages)\n\n // Send the request with your HTTP client\n use response &lt;- result.try(http_client.send(req))\n \n // Handle the response with the appropriate decoder\n client.handle_response(response, using: agent.response_decoder())\n \nSynonyms:\ngleamstral/agent.complete_request\ngleamstral/agent complete_request","url":"gleamstral/agent.html#complete_request"},{"doc":"gleamstral/agent","title":"handle_response","content":"pub fn handle_response(\n  response: Response(String),\n) -&gt; Result(gleamstral/agent.Response, Error)\n Handle HTTP responses from an agent request\n\n This is a convenience function that automatically uses the agent response decoder,\n so you don&#39;t need to pass it manually.\n\n ## Example\n\n \n agent.handle_response(response)\n \nSynonyms:\ngleamstral/agent.handle_response\ngleamstral/agent handle_response","url":"gleamstral/agent.html#handle_response"},{"doc":"gleamstral/agent","title":"new","content":"pub fn new(client: Client) -&gt; Agent\n Creates a new Agent with default configuration using the provided client\n\n ### Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let agent = agent.new(client)\n \nSynonyms:\ngleamstral/agent.new\ngleamstral/agent new","url":"gleamstral/agent.html#new"},{"doc":"gleamstral/agent","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/agent.response_decoder\ngleamstral/agent response_decoder","url":"gleamstral/agent.html#response_decoder"},{"doc":"gleamstral/agent","title":"set_frequency_penalty","content":"pub fn set_frequency_penalty(\n  agent: Agent,\n  frequency_penalty: Float,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_frequency_penalty\ngleamstral/agent set_frequency_penalty","url":"gleamstral/agent.html#set_frequency_penalty"},{"doc":"gleamstral/agent","title":"set_max_tokens","content":"pub fn set_max_tokens(agent: Agent, max_tokens: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_max_tokens\ngleamstral/agent set_max_tokens","url":"gleamstral/agent.html#set_max_tokens"},{"doc":"gleamstral/agent","title":"set_n","content":"pub fn set_n(agent: Agent, n: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_n\ngleamstral/agent set_n","url":"gleamstral/agent.html#set_n"},{"doc":"gleamstral/agent","title":"set_prediction","content":"pub fn set_prediction(\n  agent: Agent,\n  prediction: Prediction,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_prediction\ngleamstral/agent set_prediction","url":"gleamstral/agent.html#set_prediction"},{"doc":"gleamstral/agent","title":"set_presence_penalty","content":"pub fn set_presence_penalty(\n  agent: Agent,\n  presence_penalty: Float,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_presence_penalty\ngleamstral/agent set_presence_penalty","url":"gleamstral/agent.html#set_presence_penalty"},{"doc":"gleamstral/agent","title":"set_random_seed","content":"pub fn set_random_seed(agent: Agent, random_seed: Int) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_random_seed\ngleamstral/agent set_random_seed","url":"gleamstral/agent.html#set_random_seed"},{"doc":"gleamstral/agent","title":"set_response_format","content":"pub fn set_response_format(\n  agent: Agent,\n  response_format: ResponseFormat,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_response_format\ngleamstral/agent set_response_format","url":"gleamstral/agent.html#set_response_format"},{"doc":"gleamstral/agent","title":"set_stop","content":"pub fn set_stop(agent: Agent, stop: List(String)) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_stop\ngleamstral/agent set_stop","url":"gleamstral/agent.html#set_stop"},{"doc":"gleamstral/agent","title":"set_stream","content":"pub fn set_stream(agent: Agent, stream: Bool) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_stream\ngleamstral/agent set_stream","url":"gleamstral/agent.html#set_stream"},{"doc":"gleamstral/agent","title":"set_tool_choice","content":"pub fn set_tool_choice(\n  agent: Agent,\n  tool_choice: ToolChoice,\n) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_tool_choice\ngleamstral/agent set_tool_choice","url":"gleamstral/agent.html#set_tool_choice"},{"doc":"gleamstral/agent","title":"set_tools","content":"pub fn set_tools(agent: Agent, tools: List(Tool)) -&gt; Agent\n\nSynonyms:\ngleamstral/agent.set_tools\ngleamstral/agent set_tools","url":"gleamstral/agent.html#set_tools"},{"doc":"gleamstral/agent","title":"gleamstral/agent","content":"","url":"gleamstral/agent.html"},{"doc":"gleamstral/model","title":"Model","content":"pub type Model {\n  MistralLarge\n  MistralSmall\n  Ministral3B\n  Ministral8B\n  PixtralLarge\n  Pixtral\n  MistralEmbed\n  MistralNemo\n  MistralSaba\n}\n\nMistralLarge\n\n\nMistralSmall\n\n\nMinistral3B\n\n\nMinistral8B\n\n\nPixtralLarge\n\n\nPixtral\n\n\nMistralEmbed\n\n\nMistralNemo\n\n\nMistralSaba\n\n\nSynonyms:\ngleamstral/model.Model\ngleamstral/model Model","url":"gleamstral/model.html#Model"},{"doc":"gleamstral/model","title":"model_decoder","content":"pub fn model_decoder() -&gt; Decoder(Model)\n\nSynonyms:\ngleamstral/model.model_decoder\ngleamstral/model model_decoder","url":"gleamstral/model.html#model_decoder"},{"doc":"gleamstral/model","title":"to_string","content":"pub fn to_string(model: Model) -&gt; String\n\nSynonyms:\ngleamstral/model.to_string\ngleamstral/model to_string","url":"gleamstral/model.html#to_string"},{"doc":"gleamstral/model","title":"gleamstral/model","content":"","url":"gleamstral/model.html"},{"doc":"gleamstral/chat","title":"Chat","content":"pub type Chat {\n  Chat(client: client.Client, config: Config)\n}\n Represents a chat conversation with configuration options\nChat(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/chat.Chat\ngleamstral/chat Chat","url":"gleamstral/chat.html#Chat"},{"doc":"gleamstral/chat","title":"ChatCompletionChoice","content":"pub type ChatCompletionChoice {\n  ChatCompletionChoice(\n    index: Int,\n    message: message.Message,\n    finish_reason: FinishReason,\n  )\n}\n\nChatCompletionChoice(\n  index: Int,\n  message: message.Message,\n  finish_reason: FinishReason,\n)\n\n\nSynonyms:\ngleamstral/chat.ChatCompletionChoice\ngleamstral/chat ChatCompletionChoice","url":"gleamstral/chat.html#ChatCompletionChoice"},{"doc":"gleamstral/chat","title":"Config","content":"pub type Config {\n  Config(\n    temperature: Float,\n    max_tokens: Int,\n    top_p: Float,\n    stream: Bool,\n    stop: List(String),\n    random_seed: Int,\n    response_format: ResponseFormat,\n    tools: List(tool.Tool),\n    tool_choice: tool.ToolChoice,\n    presence_penalty: Float,\n    frequency_penalty: Float,\n    n: Int,\n    prediction: Prediction,\n    safe_prompt: Bool,\n  )\n}\n\nConfig(\n  temperature: Float,\n  max_tokens: Int,\n  top_p: Float,\n  stream: Bool,\n  stop: List(String),\n  random_seed: Int,\n  response_format: ResponseFormat,\n  tools: List(tool.Tool),\n  tool_choice: tool.ToolChoice,\n  presence_penalty: Float,\n  frequency_penalty: Float,\n  n: Int,\n  prediction: Prediction,\n  safe_prompt: Bool,\n)\n\n\nSynonyms:\ngleamstral/chat.Config\ngleamstral/chat Config","url":"gleamstral/chat.html#Config"},{"doc":"gleamstral/chat","title":"FinishReason","content":"pub type FinishReason {\n  Stop\n  Length\n  ModelLength\n  Err\n  ToolCalls\n}\n\nStop\n\n\nLength\n\n\nModelLength\n\n\nErr\n\n\nToolCalls\n\n\nSynonyms:\ngleamstral/chat.FinishReason\ngleamstral/chat FinishReason","url":"gleamstral/chat.html#FinishReason"},{"doc":"gleamstral/chat","title":"Prediction","content":"pub type Prediction {\n  Content(String)\n}\n\nContent(String)\n\n\nSynonyms:\ngleamstral/chat.Prediction\ngleamstral/chat Prediction","url":"gleamstral/chat.html#Prediction"},{"doc":"gleamstral/chat","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    created: Int,\n    model: String,\n    choices: List(ChatCompletionChoice),\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  created: Int,\n  model: String,\n  choices: List(ChatCompletionChoice),\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/chat.Response\ngleamstral/chat Response","url":"gleamstral/chat.html#Response"},{"doc":"gleamstral/chat","title":"ResponseFormat","content":"pub type ResponseFormat {\n  JsonObject\n  JsonSchema(schema: json.Json, name: String)\n  Text\n}\n\nJsonObject\n\n\nJsonSchema(schema: json.Json, name: String)\n\n\nText\n\n\nSynonyms:\ngleamstral/chat.ResponseFormat\ngleamstral/chat ResponseFormat","url":"gleamstral/chat.html#ResponseFormat"},{"doc":"gleamstral/chat","title":"Usage","content":"pub type Usage {\n  Usage(\n    prompt_tokens: Int,\n    completion_tokens: Int,\n    total_tokens: Int,\n  )\n}\n\nUsage(\n  prompt_tokens: Int,\n  completion_tokens: Int,\n  total_tokens: Int,\n)\n\n\nSynonyms:\ngleamstral/chat.Usage\ngleamstral/chat Usage","url":"gleamstral/chat.html#Usage"},{"doc":"gleamstral/chat","title":"complete_request","content":"pub fn complete_request(\n  chat: Chat,\n  model: Model,\n  messages: List(Message),\n) -&gt; Request(String)\n Creates an HTTP request for the Chat API endpoint\n\n This function prepares a request to be sent to the Mistral AI Chat API.\n It needs to be paired with an HTTP client to actually send the request,\n and the response should be handled with client.handle_response using \n the appropriate decoder.\n\n ### Example\n\n \n // Create the request\n let req = chat\n   |&gt; chat.set_temperature(0.7)\n   |&gt; chat.complete_request(model.MistralSmall, messages)\n\n // Send the request with your HTTP client\n use response &lt;- result.try(http_client.send(req))\n \n // Handle the response with the appropriate decoder\n client.handle_response(response, using: chat.response_decoder())\n \nSynonyms:\ngleamstral/chat.complete_request\ngleamstral/chat complete_request","url":"gleamstral/chat.html#complete_request"},{"doc":"gleamstral/chat","title":"handle_response","content":"pub fn handle_response(\n  response: Response(String),\n) -&gt; Result(gleamstral/chat.Response, Error)\n Handle HTTP responses from a chat completion request\n\n ### Example\n \n \n let assert Ok(response) =\n   chat.complete_request(chat, model.MistralSmall, messages)\n   |&gt; httpc.send\n let assert Ok(response) =\n   chat.handle_response(chat, response)\n \nSynonyms:\ngleamstral/chat.handle_response\ngleamstral/chat handle_response","url":"gleamstral/chat.html#handle_response"},{"doc":"gleamstral/chat","title":"new","content":"pub fn new(client: Client) -&gt; Chat\n Creates a new Chat with default configuration using the provided client\n\n ## Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let chat = chat.new(client)\n \nSynonyms:\ngleamstral/chat.new\ngleamstral/chat new","url":"gleamstral/chat.html#new"},{"doc":"gleamstral/chat","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/chat.response_decoder\ngleamstral/chat response_decoder","url":"gleamstral/chat.html#response_decoder"},{"doc":"gleamstral/chat","title":"set_frequency_penalty","content":"pub fn set_frequency_penalty(\n  chat: Chat,\n  frequency_penalty: Float,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_frequency_penalty\ngleamstral/chat set_frequency_penalty","url":"gleamstral/chat.html#set_frequency_penalty"},{"doc":"gleamstral/chat","title":"set_max_tokens","content":"pub fn set_max_tokens(chat: Chat, max_tokens: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_max_tokens\ngleamstral/chat set_max_tokens","url":"gleamstral/chat.html#set_max_tokens"},{"doc":"gleamstral/chat","title":"set_n","content":"pub fn set_n(chat: Chat, n: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_n\ngleamstral/chat set_n","url":"gleamstral/chat.html#set_n"},{"doc":"gleamstral/chat","title":"set_prediction","content":"pub fn set_prediction(chat: Chat, prediction: Prediction) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_prediction\ngleamstral/chat set_prediction","url":"gleamstral/chat.html#set_prediction"},{"doc":"gleamstral/chat","title":"set_presence_penalty","content":"pub fn set_presence_penalty(\n  chat: Chat,\n  presence_penalty: Float,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_presence_penalty\ngleamstral/chat set_presence_penalty","url":"gleamstral/chat.html#set_presence_penalty"},{"doc":"gleamstral/chat","title":"set_random_seed","content":"pub fn set_random_seed(chat: Chat, random_seed: Int) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_random_seed\ngleamstral/chat set_random_seed","url":"gleamstral/chat.html#set_random_seed"},{"doc":"gleamstral/chat","title":"set_response_format","content":"pub fn set_response_format(\n  chat: Chat,\n  response_format: ResponseFormat,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_response_format\ngleamstral/chat set_response_format","url":"gleamstral/chat.html#set_response_format"},{"doc":"gleamstral/chat","title":"set_safe_prompt","content":"pub fn set_safe_prompt(chat: Chat, safe_prompt: Bool) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_safe_prompt\ngleamstral/chat set_safe_prompt","url":"gleamstral/chat.html#set_safe_prompt"},{"doc":"gleamstral/chat","title":"set_stop","content":"pub fn set_stop(chat: Chat, stop: List(String)) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_stop\ngleamstral/chat set_stop","url":"gleamstral/chat.html#set_stop"},{"doc":"gleamstral/chat","title":"set_stream","content":"pub fn set_stream(chat: Chat, stream: Bool) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_stream\ngleamstral/chat set_stream","url":"gleamstral/chat.html#set_stream"},{"doc":"gleamstral/chat","title":"set_temperature","content":"pub fn set_temperature(chat: Chat, temperature: Float) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_temperature\ngleamstral/chat set_temperature","url":"gleamstral/chat.html#set_temperature"},{"doc":"gleamstral/chat","title":"set_tool_choice","content":"pub fn set_tool_choice(\n  chat: Chat,\n  tool_choice: ToolChoice,\n) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_tool_choice\ngleamstral/chat set_tool_choice","url":"gleamstral/chat.html#set_tool_choice"},{"doc":"gleamstral/chat","title":"set_tools","content":"pub fn set_tools(chat: Chat, tools: List(Tool)) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_tools\ngleamstral/chat set_tools","url":"gleamstral/chat.html#set_tools"},{"doc":"gleamstral/chat","title":"set_top_p","content":"pub fn set_top_p(chat: Chat, top_p: Float) -&gt; Chat\n\nSynonyms:\ngleamstral/chat.set_top_p\ngleamstral/chat set_top_p","url":"gleamstral/chat.html#set_top_p"},{"doc":"gleamstral/chat","title":"gleamstral/chat","content":"","url":"gleamstral/chat.html"},{"doc":"gleamstral/embeddings","title":"Config","content":"pub type Config {\n  Config(encoding_format: EncodingFormat)\n}\n\nConfig(encoding_format: EncodingFormat)\n\n\nSynonyms:\ngleamstral/embeddings.Config\ngleamstral/embeddings Config","url":"gleamstral/embeddings.html#Config"},{"doc":"gleamstral/embeddings","title":"EmbeddingData","content":"pub type EmbeddingData {\n  EmbeddingData(index: Int, embedding: List(Float))\n}\n\nEmbeddingData(index: Int, embedding: List(Float))\n\n\nSynonyms:\ngleamstral/embeddings.EmbeddingData\ngleamstral/embeddings EmbeddingData","url":"gleamstral/embeddings.html#EmbeddingData"},{"doc":"gleamstral/embeddings","title":"Embeddings","content":"pub type Embeddings {\n  Embeddings(client: client.Client, config: Config)\n}\n Represents an embeddings service with configuration options\n\n Use this to generate vector embeddings for text inputs\nEmbeddings(client: client.Client, config: Config)\n\n\nSynonyms:\ngleamstral/embeddings.Embeddings\ngleamstral/embeddings Embeddings","url":"gleamstral/embeddings.html#Embeddings"},{"doc":"gleamstral/embeddings","title":"EncodingFormat","content":"pub type EncodingFormat {\n  Float\n}\n Format of the generated embeddings\n\n - `Float`: Standard floating point format for vector embeddings\nFloat\n\n\nSynonyms:\ngleamstral/embeddings.EncodingFormat\ngleamstral/embeddings EncodingFormat","url":"gleamstral/embeddings.html#EncodingFormat"},{"doc":"gleamstral/embeddings","title":"Response","content":"pub type Response {\n  Response(\n    id: String,\n    object: String,\n    data: List(EmbeddingData),\n    model: String,\n    usage: Usage,\n  )\n}\n\nResponse(\n  id: String,\n  object: String,\n  data: List(EmbeddingData),\n  model: String,\n  usage: Usage,\n)\n\n\nSynonyms:\ngleamstral/embeddings.Response\ngleamstral/embeddings Response","url":"gleamstral/embeddings.html#Response"},{"doc":"gleamstral/embeddings","title":"Usage","content":"pub type Usage {\n  Usage(prompt_tokens: Int, total_tokens: Int)\n}\n\nUsage(prompt_tokens: Int, total_tokens: Int)\n\n\nSynonyms:\ngleamstral/embeddings.Usage\ngleamstral/embeddings Usage","url":"gleamstral/embeddings.html#Usage"},{"doc":"gleamstral/embeddings","title":"create_request","content":"pub fn create_request(\n  embeddings: Embeddings,\n  model: Model,\n  inputs: List(String),\n) -&gt; Request(String)\n Creates an HTTP request for the Embeddings API endpoint\n\n This function prepares a request to be sent to the Mistral AI Embeddings API.\n It needs to be paired with an HTTP client to actually send the request,\n and the response should be handled with client.handle_response using \n the appropriate decoder.\n\n ### Example\n\n \n // Create the request\n let req = embeddings\n   |&gt; embeddings.create_request(\n     model.EmbeddingMistral,\n     [&quot;Text to embed&quot;, &quot;Another text to embed&quot;]\n   )\n\n // Send the request with your HTTP client\n use response &lt;- result.try(http_client.send(req))\n \n // Handle the response with the appropriate decoder\n client.handle_response(response, using: embeddings.response_decoder())\n \nSynonyms:\ngleamstral/embeddings.create_request\ngleamstral/embeddings create_request","url":"gleamstral/embeddings.html#create_request"},{"doc":"gleamstral/embeddings","title":"handle_response","content":"pub fn handle_response(\n  response: Response(String),\n) -&gt; Result(gleamstral/embeddings.Response, Error)\n Handle HTTP responses from an embeddings request\n\n ### Example\n\n \n let assert Ok(response) =\n   embeddings.create_request(embeddings, model.EmbeddingMistral, [&quot;Text to embed&quot;])\n   |&gt; httpc.send\n let assert Ok(response) =\n   embeddings.handle_response(response)\n \nSynonyms:\ngleamstral/embeddings.handle_response\ngleamstral/embeddings handle_response","url":"gleamstral/embeddings.html#handle_response"},{"doc":"gleamstral/embeddings","title":"new","content":"pub fn new(client: Client) -&gt; Embeddings\n Creates a new Embeddings instance with default configuration using the provided client\n\n ### Example\n\n \n let client = client.new(&quot;your-api-key&quot;)\n let embeddings = embeddings.new(client)\n \nSynonyms:\ngleamstral/embeddings.new\ngleamstral/embeddings new","url":"gleamstral/embeddings.html#new"},{"doc":"gleamstral/embeddings","title":"response_decoder","content":"pub fn response_decoder() -&gt; Decoder(Response)\n\nSynonyms:\ngleamstral/embeddings.response_decoder\ngleamstral/embeddings response_decoder","url":"gleamstral/embeddings.html#response_decoder"},{"doc":"gleamstral/embeddings","title":"set_encoding_format","content":"pub fn set_encoding_format(\n  embeddings: Embeddings,\n  encoding_format: EncodingFormat,\n) -&gt; Embeddings\n\nSynonyms:\ngleamstral/embeddings.set_encoding_format\ngleamstral/embeddings set_encoding_format","url":"gleamstral/embeddings.html#set_encoding_format"},{"doc":"gleamstral/embeddings","title":"gleamstral/embeddings","content":"","url":"gleamstral/embeddings.html"}]);